@@ -7,7 +7,7 @@ use Storable qw( freeze thaw );
 
 use v5.10;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 extends 'Parallel::ForkManager';
 
@@ -99,11 +99,7 @@ sub update_stats_pct {
 before start => sub {
     my $self = shift;
  
-    #
-    # Try to get an idle % as quickly as possible (it will be NaN initially)
-    #
-    return if $self->idle ne 'NaN' 
-              && time - $self->last_update < $self->update_frequency;
+    return if time - $self->last_update < $self->update_frequency;
 
     $self->update_stats_pct;
 
@@ -315,7 +311,7 @@ Parallel::ForkManager::Scaled - Run processes in parallel based on CPU usage
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -406,9 +402,6 @@ Before each call to C<start()> the time is compared with the last time a
 check/update was performed. If this much time has passed, a new check will be
 made of how busy the CPU is and the number of processes may be adjusted.
 
-This is ignored until an idle % can be calculated (it's NaN when the object
-is first built).
-
 default: 1
 
 =item B<idle_target>
@@ -539,8 +532,7 @@ Probably best to avoid them :)
 
 This method will attempt to update CPU stats (idle, etc). It is 
 automatically called before each child process is C<start()>ed if
-at least B<update_frequency> seconds has elapsed since the last call
-or the current idle % is NaN.
+at least B<update_frequency> seconds has elapsed since the last call.
 
 If not enough time has elapsed since the last call to B<update_stats_pct> it's
 possible to get NaN for the new B<idle> stat. In this case no updates
